@@ -27,21 +27,21 @@ const AREA = 'customer';
 require __DIR__ . '/lib/init.php';
 
 use Froxlor\Api\Commands\Customers as Customers;
+use Froxlor\Cron\TaskId;
 use Froxlor\CurrentUser;
 use Froxlor\Database\Database;
 use Froxlor\Froxlor;
 use Froxlor\FroxlorLogger;
+use Froxlor\Language;
 use Froxlor\Settings;
+use Froxlor\System\Cronjob;
 use Froxlor\System\Crypt;
 use Froxlor\UI\Panel\UI;
 use Froxlor\UI\Response;
 use Froxlor\Validate\Validate;
-use Froxlor\Language;
-use Froxlor\System\Cronjob;
-use Froxlor\Cron\TaskId;
 
 if ($action == 'logout') {
-	$log->logAction(FroxlorLogger::USR_ACTION, LOG_NOTICE, 'logged out');
+	$log->logAction(FroxlorLogger::USR_ACTION, LOG_INFO, 'logged out');
 
 	unset($_SESSION['userinfo']);
 	CurrentUser::setData();
@@ -66,7 +66,7 @@ if ($action == 'logout') {
 }
 
 if ($page == 'overview') {
-	$log->logAction(FroxlorLogger::USR_ACTION, LOG_NOTICE, "viewed customer_index");
+	$log->logAction(FroxlorLogger::USR_ACTION, LOG_INFO, "viewed customer_index");
 
 	$domain_stmt = Database::prepare("SELECT `domain` FROM `" . TABLE_PANEL_DOMAINS . "`
 		WHERE `customerid` = :customerid
@@ -114,15 +114,20 @@ if ($page == 'overview') {
 	$userinfo['traffic_bytes'] = ($userinfo['traffic'] > -1) ? $userinfo['traffic'] * 1024 : -1;
 	$userinfo['traffic_bytes_used'] = $userinfo['traffic_used'] * 1024;
 
+	if (Settings::Get('system.mail_quota_enabled')) {
+		$userinfo['email_quota_bytes'] = ($userinfo['email_quota'] > -1) ? $userinfo['email_quota'] * 1024 : -1;
+		$userinfo['email_quota_bytes_used'] = $userinfo['email_quota_used'] * 1024;
+	}
+
 	if ($usages) {
 		$userinfo['diskspace_bytes_used'] = $usages['webspace'] * 1024;
-		$userinfo['mailspace_used']  = $usages['mail'] * 1024;
+		$userinfo['mailspace_used'] = $usages['mail'] * 1024;
 		$userinfo['dbspace_used'] = $usages['mysql'] * 1024;
 		$userinfo['total_bytes_used'] = ($usages['webspace'] + $usages['mail'] + $usages['mysql']) * 1024;
 	} else {
 		$userinfo['diskspace_bytes_used'] = 0;
 		$userinfo['total_bytes_used'] = 0;
-		$userinfo['mailspace_used']  = 0;
+		$userinfo['mailspace_used'] = 0;
 		$userinfo['dbspace_used'] = 0;
 	}
 
@@ -131,141 +136,138 @@ if ($page == 'overview') {
 		'domains' => $domainArray,
 		'stdsubdomain' => $stdsubdomain
 	]);
-} elseif ($page == 'change_password') {
-	if (isset($_POST['send']) && $_POST['send'] == 'send') {
-		$old_password = Validate::validate($_POST['old_password'], 'old password');
+} elseif ($page == 'profile') {
+	$languages = Language::getLanguages();
 
-		if (!Crypt::validatePasswordLogin($userinfo, $old_password, TABLE_PANEL_CUSTOMERS, 'customerid')) {
-			Response::standardError('oldpasswordnotcorrect');
-		}
+	if (!empty($_POST)) {
+		if ($_POST['send'] == 'changepassword') {
+			$old_password = Validate::validate($_POST['old_password'], 'old password');
 
-		try {
-			$new_password = Crypt::validatePassword($_POST['new_password'], 'new password');
-			$new_password_confirm = Crypt::validatePassword($_POST['new_password_confirm'], 'new password confirm');
-		} catch (Exception $e) {
-			Response::dynamicError($e->getMessage());
-		}
+			if (!Crypt::validatePasswordLogin($userinfo, $old_password, TABLE_PANEL_CUSTOMERS, 'customerid')) {
+				Response::standardError('oldpasswordnotcorrect');
+			}
 
-		if ($old_password == '') {
-			Response::standardError([
-				'stringisempty',
-				'changepassword.old_password'
-			]);
-		} elseif ($new_password == '') {
-			Response::standardError([
-				'stringisempty',
-				'changepassword.new_password'
-			]);
-		} elseif ($new_password_confirm == '') {
-			Response::standardError([
-				'stringisempty',
-				'changepassword.new_password_confirm'
-			]);
-		} elseif ($new_password != $new_password_confirm) {
-			Response::standardError('newpasswordconfirmerror');
-		} else {
-			// Update user password
 			try {
-				Customers::getLocal($userinfo, [
-					'id' => $userinfo['customerid'],
-					'new_customer_password' => $new_password
-				])->update();
+				$new_password = Crypt::validatePassword($_POST['new_password'], 'new password');
+				$new_password_confirm = Crypt::validatePassword($_POST['new_password_confirm'], 'new password confirm');
 			} catch (Exception $e) {
 				Response::dynamicError($e->getMessage());
 			}
-			$log->logAction(FroxlorLogger::USR_ACTION, LOG_NOTICE, 'changed password');
 
-			// Update ftp password
-			if (isset($_POST['change_main_ftp']) && $_POST['change_main_ftp'] == 'true') {
-				$cryptPassword = Crypt::makeCryptPassword($new_password);
-				$stmt = Database::prepare("UPDATE `" . TABLE_FTP_USERS . "`
+			if ($old_password == '') {
+				Response::standardError([
+					'stringisempty',
+					'changepassword.old_password'
+				]);
+			} elseif ($new_password == '') {
+				Response::standardError([
+					'stringisempty',
+					'changepassword.new_password'
+				]);
+			} elseif ($new_password_confirm == '') {
+				Response::standardError([
+					'stringisempty',
+					'changepassword.new_password_confirm'
+				]);
+			} elseif ($new_password != $new_password_confirm) {
+				Response::standardError('newpasswordconfirmerror');
+			} else {
+				// Update user password
+				try {
+					Customers::getLocal($userinfo, [
+						'id' => $userinfo['customerid'],
+						'new_customer_password' => $new_password
+					])->update();
+				} catch (Exception $e) {
+					Response::dynamicError($e->getMessage());
+				}
+				$log->logAction(FroxlorLogger::USR_ACTION, LOG_NOTICE, 'changed password');
+
+				// Update ftp password
+				if (isset($_POST['change_main_ftp']) && $_POST['change_main_ftp'] == 'true') {
+					$cryptPassword = Crypt::makeCryptPassword($new_password);
+					$stmt = Database::prepare("UPDATE `" . TABLE_FTP_USERS . "`
 					SET `password` = :password
 					WHERE `customerid` = :customerid
 					AND `username` = :username");
-				$params = [
-					"password" => $cryptPassword,
-					"customerid" => $userinfo['customerid'],
-					"username" => $userinfo['loginname']
-				];
-				Database::pexecute($stmt, $params);
-				$log->logAction(FroxlorLogger::USR_ACTION, LOG_NOTICE, 'changed main ftp password');
-			}
+					$params = [
+						"password" => $cryptPassword,
+						"customerid" => $userinfo['customerid'],
+						"username" => $userinfo['loginname']
+					];
+					Database::pexecute($stmt, $params);
+					$log->logAction(FroxlorLogger::USR_ACTION, LOG_NOTICE, 'changed main ftp password');
+				}
 
-			// Update statistics password
-			if (isset($_POST['change_stats']) && $_POST['change_stats'] == 'true') {
-				$new_stats_password = Crypt::makeCryptPassword($new_password, true);
+				// Update statistics password
+				if (isset($_POST['change_stats']) && $_POST['change_stats'] == 'true') {
+					$new_stats_password = Crypt::makeCryptPassword($new_password, true);
 
-				$stmt = Database::prepare("UPDATE `" . TABLE_PANEL_HTPASSWDS . "`
+					$stmt = Database::prepare("UPDATE `" . TABLE_PANEL_HTPASSWDS . "`
 					SET `password` = :password
 					WHERE `customerid` = :customerid
 					AND `username` = :username");
-				$params = [
-					"password" => $new_stats_password,
-					"customerid" => $userinfo['customerid'],
-					"username" => $userinfo['loginname']
-				];
-				Database::pexecute($stmt, $params);
-				Cronjob::inserttask(TaskId::REBUILD_VHOST);
-			}
+					$params = [
+						"password" => $new_stats_password,
+						"customerid" => $userinfo['customerid'],
+						"username" => $userinfo['loginname']
+					];
+					Database::pexecute($stmt, $params);
+					Cronjob::inserttask(TaskId::REBUILD_VHOST);
+				}
 
+				Response::redirectTo($filename);
+			}
+		} elseif ($_POST['send'] == 'changetheme') {
+			if (Settings::Get('panel.allow_theme_change_customer') == 1) {
+				$theme = Validate::validate($_POST['theme'], 'theme');
+				try {
+					Customers::getLocal($userinfo, [
+						'id' => $userinfo['customerid'],
+						'theme' => $theme
+					])->update();
+				} catch (Exception $e) {
+					Response::dynamicError($e->getMessage());
+				}
+
+				$log->logAction(FroxlorLogger::USR_ACTION, LOG_NOTICE, "changed default theme to '" . $theme . "'");
+			}
+			Response::redirectTo($filename);
+		} elseif ($_POST['send'] == 'changelanguage') {
+			$def_language = Validate::validate($_POST['def_language'], 'default language');
+			if (isset($languages[$def_language])) {
+				try {
+					Customers::getLocal($userinfo, [
+						'id' => $userinfo['customerid'],
+						'def_language' => $def_language
+					])->update();
+					CurrentUser::setField('language', $def_language);
+				} catch (Exception $e) {
+					Response::dynamicError($e->getMessage());
+				}
+			}
+			$log->logAction(FroxlorLogger::USR_ACTION, LOG_NOTICE, "changed default language to '" . $def_language . "'");
 			Response::redirectTo($filename);
 		}
 	} else {
-		UI::view('user/change_password.html.twig');
-	}
-} elseif ($page == 'change_language') {
-	$languages = Language::getLanguages();
-	if (isset($_POST['send']) && $_POST['send'] == 'send') {
-		$def_language = Validate::validate($_POST['def_language'], 'default language');
-		if (isset($languages[$def_language])) {
-			try {
-				Customers::getLocal($userinfo, [
-					'id' => $userinfo['customerid'],
-					'def_language' => $def_language
-				])->update();
-				CurrentUser::setField('language', $def_language);
-			} catch (Exception $e) {
-				Response::dynamicError($e->getMessage());
-			}
+		// change theme
+		$default_theme = Settings::Get('panel.default_theme');
+		if ($userinfo['theme'] != '') {
+			$default_theme = $userinfo['theme'];
 		}
-		$log->logAction(FroxlorLogger::USR_ACTION, LOG_NOTICE, "changed default language to '" . $def_language . "'");
-		Response::redirectTo($filename);
-	} else {
+		$themes_avail = UI::getThemes();
+
+		// change language
 		$default_lang = Settings::Get('panel.standardlanguage');
 		if ($userinfo['def_language'] != '') {
 			$default_lang = $userinfo['def_language'];
 		}
 
-		UI::view('user/change_language.html.twig', [
-			'languages' => $languages,
-			'default_lang' => $default_lang
-		]);
-	}
-} elseif ($page == 'change_theme') {
-	if (isset($_POST['send']) && $_POST['send'] == 'send') {
-		$theme = Validate::validate($_POST['theme'], 'theme');
-		try {
-			Customers::getLocal($userinfo, [
-				'id' => $userinfo['customerid'],
-				'theme' => $theme
-			])->update();
-		} catch (Exception $e) {
-			Response::dynamicError($e->getMessage());
-		}
-
-		$log->logAction(FroxlorLogger::USR_ACTION, LOG_NOTICE, "changed default theme to '" . $theme . "'");
-		Response::redirectTo($filename);
-	} else {
-		$default_theme = Settings::Get('panel.default_theme');
-		if ($userinfo['theme'] != '') {
-			$default_theme = $userinfo['theme'];
-		}
-
-		$themes_avail = UI::getThemes();
-
-		UI::view('user/change_theme.html.twig', [
+		UI::view('user/profile.html.twig', [
 			'themes' => $themes_avail,
-			'default_theme' => $default_theme
+			'default_theme' => $default_theme,
+			'languages' => $languages,
+			'default_lang' => $default_lang,
 		]);
 	}
 } elseif ($page == 'send_error_report' && Settings::Get('system.allow_error_report_customer') == '1') {
