@@ -25,6 +25,7 @@
 
 namespace Froxlor\UI\Callbacks;
 
+use Froxlor\Database\Database;
 use Froxlor\Domain\Domain as DDomain;
 use Froxlor\FileDir;
 use Froxlor\Settings;
@@ -32,6 +33,11 @@ use Froxlor\UI\Panel\UI;
 
 class Domain
 {
+	public static function domainLink(array $attributes)
+	{
+		return '<a href="https://' . $attributes['data'] . '" target="_blank">' . $attributes['data'] . '</a>';
+	}
+
 	public static function domainWithCustomerLink(array $attributes)
 	{
 		$linker = UI::getLinker();
@@ -51,6 +57,9 @@ class Domain
 	public static function domainTarget(array $attributes)
 	{
 		if (empty($attributes['fields']['aliasdomain'])) {
+			if ($attributes['fields']['deactivated']) {
+				return lng('admin.deactivated');
+			}
 			// path or redirect
 			if (preg_match('/^https?\:\/\//', $attributes['fields']['documentroot'])) {
 				return [
@@ -76,11 +85,11 @@ class Domain
 	{
 		$result = '';
 		if ($attributes['fields']['parentdomainid'] != 0) {
-				$result = '<i class="fa-solid fa-turn-up me-2 fa-rotate-90 opacity-50"></i>';
+			$result = '<i class="fa-solid fa-turn-up me-2 fa-rotate-90 opacity-50"></i>';
 		}
 		$result .= '<a href="http://' . $attributes['data'] . '" target="_blank">' . $attributes['data'] . '</a>';
 		// check for statistics if parentdomainid==0 to show stats-link for customers
-		if ((int)UI::getCurrentUser()['adminsession'] == 0 && $attributes['fields']['parentdomainid'] == 0) {
+		if ((int)UI::getCurrentUser()['adminsession'] == 0 && $attributes['fields']['parentdomainid'] == 0 && $attributes['fields']['deactivated'] == 0) {
 			$statsapp = Settings::Get('system.traffictool');
 			$result .= ' <a href="http://' . $attributes['data'] . '/' . $statsapp . '" rel="external" target="_blank" title="' . lng('domains.statstics') . '"><i class="fa-solid fa-chart-line text-secondary"></i></a>';
 		}
@@ -95,12 +104,12 @@ class Domain
 
 	public static function canEdit(array $attributes): bool
 	{
-		return (bool)$attributes['fields']['caneditdomain'];
+		return (bool)($attributes['fields']['caneditdomain'] && !$attributes['fields']['deactivated']);
 	}
 
 	public static function canViewLogs(array $attributes): bool
 	{
-		if ((int)$attributes['fields']['email_only'] == 0) {
+		if ((int)$attributes['fields']['email_only'] == 0 && !$attributes['fields']['deactivated']) {
 			if ((int)UI::getCurrentUser()['adminsession'] == 0 && (bool)UI::getCurrentUser()['logviewenabled']) {
 				return true;
 			} elseif ((int)UI::getCurrentUser()['adminsession'] == 1) {
@@ -129,7 +138,8 @@ class Domain
 			&& UI::getCurrentUser()['dnsenabled'] == '1'
 			&& $attributes['fields']['caneditdomain'] == '1'
 			&& Settings::Get('system.bind_enable') == '1'
-			&& Settings::Get('system.dnsenabled') == '1';
+			&& Settings::Get('system.dnsenabled') == '1'
+			&& !$attributes['fields']['deactivated'];
 	}
 
 	public static function adminCanEditDNS(array $attributes): bool
@@ -152,6 +162,7 @@ class Domain
 			&& (int)$attributes['fields']['caneditdomain'] == 1
 			&& (int)$attributes['fields']['letsencrypt'] == 0
 			&& (int)$attributes['fields']['email_only'] == 0
+			&& !$attributes['fields']['deactivated']
 		) {
 			return true;
 		}
@@ -184,13 +195,11 @@ class Domain
 		// specified certificate for domain
 		if ($attributes['fields']['domain_hascert'] == 1) {
 			$result['icon'] .= ' text-success';
-		}
-		// shared certificates (e.g. subdomain if domain where certificate is specified)
+		} // shared certificates (e.g. subdomain of domain where certificate is specified)
 		elseif ($attributes['fields']['domain_hascert'] == 2) {
 			$result['icon'] .= ' text-warning';
 			$result['title'] .= "\n" . lng('panel.ssleditor_infoshared');
-		}
-		// no certificate specified, using global fallbacks (IPs and Ports or if empty SSL settings)
+		} // no certificate specified, using global fallbacks (IPs and Ports or if empty SSL settings)
 		elseif ($attributes['fields']['domain_hascert'] == 0) {
 			$result['icon'] .= ' text-danger';
 			$result['title'] .= "\n" . lng('panel.ssleditor_infoglobal');
@@ -212,4 +221,22 @@ class Domain
 		}
 		return lng('panel.empty');
 	}
+
+	public static function getPhpConfigName(array $attributes): string
+	{
+		$sel_stmt = Database::prepare("SELECT `description` FROM `" . TABLE_PANEL_PHPCONFIGS . "` WHERE `id` = :id");
+		$phpconfig = Database::pexecute_first($sel_stmt, ['id' => $attributes['data']]);
+		if ((int)UI::getCurrentUser()['adminsession'] == 1) {
+			$linker = UI::getLinker();
+			$result = '<a href="' . $linker->getLink([
+				'section' => 'phpsettings',
+				'page' => 'overview',
+				'searchfield' => 'c.id',
+				'searchtext' => $attributes['data'],
+			]) . '">' . $phpconfig['description'] . '</a>';
+		} else {
+			$result = $phpconfig['description'];
+		}
+		return $result;
+	}
 }
